@@ -3,9 +3,8 @@ function( d ){
   trt <- max(d)
   b   <- nrow(d)
   k   <- ncol(d)
-  a   <- sample(trt)
-  for(i in 1:b){
-    d[i,] <- a[d[i,]]                       # Permutes treatment labels
-  }
   d <- d[sample(b),]                        # Permutes rows
-  d}
+  a <- sample(trt)                          # Permutes treatment labels
+  matrix(a[d],nc=k)}
+
+  
